/*
 * Copyright (C) 2013 The Android Open Source Project
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package com.android.internal.inputmethod;

import android.content.Context;
import android.graphics.Rect;
import android.util.AttributeSet;
import android.view.View;
import android.view.ViewGroup;
import android.widget.LinearLayout;

public class InputMethodRoot extends LinearLayout {

    private View mNavigationGuard;

    public InputMethodRoot(Context context) {
        this(context, null);
    }

    public InputMethodRoot(Context context, AttributeSet attrs) {
        this(context, attrs, 0);
    }

    public InputMethodRoot(Context context, AttributeSet attrs, int defStyle) {
        super(context, attrs);
    }

    @Override
    protected void onAttachedToWindow() {
        super.onAttachedToWindow();
        requestFitSystemWindows();
    }

    @Override
    protected boolean fitSystemWindows(Rect insets) {
        if (mNavigationGuard == null) {
            mNavigationGuard = findViewById(com.android.internal.R.id.navigationGuard);
        }
        if (mNavigationGuard == null) {
            return super.fitSystemWindows(insets);
        }
        ViewGroup.LayoutParams lp = mNavigationGuard.getLayoutParams();
        lp.height = insets.bottom;
        mNavigationGuard.setLayoutParams(lp);
        return true;
    }
}
